################################################################################
#	Makefile settings for BDS System
################################################################################
#

# Build override settings
-include ${TOP}/Local.mk

# The main version
PROJECT		= BDS
VERSION		= 3.1.4
RELEASE		= 1.beam
SCHEMA_VERSION	= 20

# The BUILD type
BUILD		= FULL
#BUILD		= CLIENT
#BUILD		= LIB
BEAMLIB_BUILD	= FULL
BEAMLIB_BUILD_UTILS	= FULL
BUILD_QT3	= yes

# The TARGET system
TARGET		?=
#TARGET		= el8
#TARGET		= fc37
#TARGET		= fc35
#TARGET		= fc33
#TARGET		= fc21
#TARGET		= el5
#TARGET		= el6
#TARGET		= fc23
#TARGET		= el7
#TARGET		= el7_9
#TARGET		= fc27

ifeq ("$(TARGET)", "")
TARGET		= $(shell cut -d " " -f2 /etc/bsystype.txt)
endif

ifeq ("$(TARGET)", "")
$(error TARGET not defined)
endif

DIST		= ${TARGET}
DEST_DIR	= 
PREFIX		= /usr/bds

# Full release Version
RPM_RELEASE	:= ${RELEASE}%{dist}
RELEASE		:= ${RELEASE}

RPM_DIR		?= ${HOME}/rpmbuild
DISTDIRBASE	?= ${HOME}/bdsdist
RPMSIGN		?= true
RPMBUILD	= rpmbuild --define "_topdir $(RPM_DIR)"

ARCH		?= $(shell arch)
ARCH_LIB	= lib

SYSETCDIR	= $(DEST_DIR)/etc
SYSSYSTEMD	= $(DEST_DIR)/usr/lib/systemd
SYSDATADIR	= $(DEST_DIR)/data
BINDIR		= $(DEST_DIR)/$(PREFIX)/bin
INCDIR		= $(DEST_DIR)/$(PREFIX)/include
LIBDIR		= $(DEST_DIR)/$(PREFIX)/${ARCH_LIB}
DOCDIR		= $(DEST_DIR)/$(PREFIX)/doc
CONFDIR		= $(DEST_DIR)/$(PREFIX)/config
DATADIR		= $(DEST_DIR)/$(PREFIX)
HTMLDIR		= $(DEST_DIR)/$(PREFIX)/html
DESKTOPDIR	= $(DEST_DIR)/usr/share/applications
DESKTOPDIRDIR	= $(DEST_DIR)/usr/share/desktop-directories
ICONSDIR	= $(DEST_DIR)/usr/share/icons
#LIBDIR		= $(DEST_DIR)/$(PREFIX)/lib/$(CPU)
ETCDIR_PHP	= ${SYSETCDIR}/php.d
ETCDIR_HTTPD	= ${SYSETCDIR}/httpd
SPEC_FILE	= bds.spec

# Build Settings
SRCINCDIR	= ${TOP}/include
SRCLIBDIR	= ${TOP}/${ARCH_LIB}
INCDIRS		= -I${SRCINCDIR} -I/usr/beamlib/include/Beamlib -I${SRCINCDIR}/Bds
LIBDIRS		= -L${SRCLIBDIR} -L/usr/beamlib/lib64
BIDL		= /usr/beamlib/bin/bidl
BUILDDOC	= 

# Use BDEV3 source
#INCDIRS		= -I${SRCINCDIR} -I${SRCINCDIR}/Bds -I/src/bdev3/beamlib/build_fedora_${TARGET}/include/Beamlib
#LIBDIRS		= -L/src/bdev3/beamlib/build_fedora_${TARGET}/${ARCH_LIB} -L${SRCLIBDIR}
#BIDL		= /src/bdev3/beamlib/bidl/build_fedora_${TARGET}/beamlib-bidl
#export LD_LIBRARY_PATH=/src/bdev3/beamlib/build_fedora_${TARGET}/${ARCH_LIB}


#COPTIONS	= -Wall -Wno-parentheses -Wreturn-type -Wno-conversion
COPTIONS	= -Wall -Wno-parentheses -Wreturn-type
DEBUGFLAGS	= -O2 -DBDEBUG
#DEBUGFLAGS	= -O0 -g -DBDEBUG
CXXFLAGS	= $(COPTIONS) $(DEBUGFLAGS) -I. $(INCDIRS) -DVERSION=\"$(VERSION)\" -DSCHEMA_VERSION=$(SCHEMA_VERSION)
CXXFLAGS	+= -D_GNU_SOURCE
CXXFLAGS	+= -MMD
CXXFLAGS	+= -Wno-deprecated -Wno-unused-but-set-variable
CXXFLAGS	+= -DBDS_FUDGE
CXXFLAGS	+= -DTARGET_${TARGET}
CPFLAGS		= -a
CFLAGS		= $(CXXFLAGS)
ASFLAGS		= $(CXXFLAGS)
LDFLAGS		= $(LIBDIRS) $(DEBUGFLAGS)
LDFLAGS 	+= -L/usr/${ARCH_LIB}/mysql
LDLIBS		= -l:libBeamlibBase.a -lpugixml -lcrypt -lz
DFLAGS		= -Y -I. $(INCDIRS)

CXX		= g++
CC		= g++
RANLIB		= true

# QT Version
QTDIR		= $(shell ls -d /usr/${ARCH_LIB}/qt-* | tail -1)
PHP_VER		= 7

# TARGET Special Settings
ifeq ("$(TARGET)", "fc16")
	ARCH		= i686
	CXXFLAGS	+=  -march=i686 -m32
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	LDLIBS		+= -lpthread
	DISTDIR		= ${DISTDIRBASE}/fedora/16
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/fedora/16
	PYTHON_VER	= 2.7
endif
ifeq ("$(TARGET)", "el5")
	ARCH		= i686
	CXXFLAGS	+= -march=i686 -m32
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	LDLIBS		+= -lpthread
	DISTDIR		= ${DISTDIRBASE}/rhel/5
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/rhel/5
	PYTHON_VER	= 2.4
endif
ifeq ("$(TARGET)", "el6")
	ARCH		= i686
	CXXFLAGS	+= -m32
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	LDLIBS		+= -lpthread
	DISTDIR		= ${DISTDIRBASE}/rhel/6
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/rhel/6
	PYTHON_VER	= 2.6
endif
ifeq ("$(TARGET)", "el6")
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	LDLIBS		+= -lpthread
	DISTDIR		= ${DISTDIRBASE}/rhel/6
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/rhel/6
	PYTHON_VER	= 2.6
endif
ifeq ("$(TARGET)", "fc21")
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -fPIC
	LDLIBS		+= -lpthread
	DISTDIR		= ${DISTDIRBASE}/fedora/21
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/fedora/21
	PYTHON_VER	= 2.7
endif
ifeq ("$(TARGET)", "fc23")
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -fPIC
	LDLIBS		+= -lpthread
	DISTDIR		= ${DISTDIRBASE}/fedora/23
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/fedora/23
	PYTHON_VER	= 2.7
endif
ifeq ("$(TARGET)", $(filter "$(TARGET)", "el7" "el7_9"))
	export PATH:=/opt/rh/rh-php72/root/usr/bin:${PATH}
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -std=gnu++11
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -I/opt/rh/rh-php72/root/usr/include/php/main -I/opt/rh/rh-php72/root/usr/include/php/Zend
	LDLIBS		+= -lpthread
	DIST		= el7
	REPOFILE	= bds-rhel.repo
	DISTDIR		= ${DISTDIRBASE}/rhel/7
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/rhel/7
	DISTDIR_DEVEL	= ${DISTDIRBASE}/development/rhel/7
	#PYTHON_VER	= 2.7
	PYTHON_VER	= 3.6m
	ETCDIR_PHP	= $(DEST_DIR)/etc/opt/rh/rh-php72/php.d
	ETCDIR_HTTPD	= $(DEST_DIR)/opt/rh/httpd24/root/etc/httpd
	#SPEC_FILE	= bds-rhel7.spec
endif
ifeq ("$(TARGET)", "fc25")
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -fPIC
	LDLIBS		+= -lpthread
	DISTDIR		= ${DISTDIRBASE}/fedora/25
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/fedora/25
	PYTHON_VER	= 2.7
endif
ifeq ("$(TARGET)", "fc27")
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -fPIC
	LDLIBS		+= -lpthread
	DISTDIR		= ${DISTDIRBASE}/fedora/27
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/fedora/27
	PYTHON_VER	= 2.7
endif
ifeq ("$(TARGET)", "fc29")
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -fPIC
	LDLIBS		+= -lpthread
	DISTDIR		= ${DISTDIRBASE}/fedora/29
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/fedora/29
	PYTHON_VER	= 2.7
endif
ifeq ("$(TARGET)", "fc31")
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -fPIC
	LDLIBS		+= -lpthread
	DISTDIR		= ${DISTDIRBASE}/fedora/31
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/fedora/31
	PYTHON_VER	= 3.7m
endif
ifeq ("$(TARGET)", "fc33")
	MAILUTILS_VERH	= 3
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -fPIC
	CXXFLAGS	+= -DMAILUTILS_VERH=${MAILUTILS_VERH}
	LDLIBS		+= -lpthread
	REPOFILE	= bds-fedora.repo
	DISTDIR		= ${DISTDIRBASE}/fedora/33
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/fedora/33
	DISTDIR_DEVEL	= ${DISTDIRBASE}/development/fedora/33
	PYTHON_VER	= 3.9
	BUILDDOC	= yes
endif
ifeq ("$(TARGET)", "fc35")
	MAILUTILS_VERH	= 3
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -fPIC
	CXXFLAGS	+= -DMAILUTILS_VERH=${MAILUTILS_VERH}
	CXXFLAGS	+= --std=c++14				# Temporary to fix build errors
	LDLIBS		+= -lpthread
	REPOFILE	= bds-fedora.repo
	DISTDIR		= ${DISTDIRBASE}/fedora/35
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/fedora/35
	DISTDIR_DEVEL	= ${DISTDIRBASE}/development/fedora/35
	PYTHON_VER	= 3.10
	PHP_VER		= 8
	BUILDDOC	= yes
endif
ifeq ("$(TARGET)", "fc37")
	MAILUTILS_VERH	= 3
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -fPIC
	CXXFLAGS	+= -DMAILUTILS_VERH=${MAILUTILS_VERH}
	CXXFLAGS	+= --std=c++14				# Temporary to fix build errors
	LDLIBS		+= -lpthread
	REPOFILE	= bds-fedora.repo
	DISTDIR		= ${DISTDIRBASE}/fedora/37
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/fedora/37
	DISTDIR_DEVEL	= ${DISTDIRBASE}/development/fedora/37
	PYTHON_VER	= 3.11
	PHP_VER		= 8
	BUILDDOC	= yes
endif
ifeq ("$(TARGET)", "el8")
	MAILUTILS_VERH	= 3
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -fPIC
	CXXFLAGS	+= -DMAILUTILS_VERH=${MAILUTILS_VERH}
	CXXFLAGS	+= --std=c++14				# Temporary to fix build errors
	LDLIBS		+= -lpthread
	REPOFILE	= bds-rhel.repo
	DISTDIR		= ${DISTDIRBASE}/rhel/8
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/rhel/8
	DISTDIR_DEVEL	= ${DISTDIRBASE}/development/rhel/8
	PYTHON_VER	= 3.9
	BUILDDOC	= no
endif
ifeq ("$(TARGET)", "el9")
	MAILUTILS_VERH	= 3
	ARCH		= x86_64
	ARCH_LIB	= lib64
	CXXFLAGS	+= -m64
	CXXFLAGS	+= -DHAVE_GETIFADDRS
	CXXFLAGS	+= -fPIC
	CXXFLAGS	+= -DMAILUTILS_VERH=${MAILUTILS_VERH}
	CXXFLAGS	+= --std=c++14				# Temporary to fix build errors
	LDLIBS		+= -lpthread
	REPOFILE	= bds-rhel.repo
	DISTDIR		= ${DISTDIRBASE}/rhel/9
	DISTDIR_TESTING	= ${DISTDIRBASE}/testing/rhel/9
	DISTDIR_DEVEL	= ${DISTDIRBASE}/development/rhel/9
	PYTHON_VER	= 3.9
	PHP_VER		= 8
	BUILDDOC	= no
	BUILD_QT3	= no
endif

.SUFFIXES: .spec

%.spec:	Config.mk
	@(if ! grep "^Version:.*${VERSION}" $@; then\
		sed -e "s/^Version:.*/Version:\t${VERSION}/" $@ > $@.tmp;\
		mv $@.tmp $@; fi) 2>&1 > /dev/null
	@(if ! grep "^Release:.*${RPM_RELEASE}" $@; then\
		sed -e "s/^Release:.*/Release:\t${RPM_RELEASE}/" $@ > $@.tmp;\
		mv $@.tmp $@; fi) 2>&1 > /dev/null
