#!/usr/bin/python
################################################################################
#	BdsEvents1.py	BDS API example code for a BDS Event Client
#	T.Barnaby,	BEAM Ltd,	2021-09-20
################################################################################
#
# This example shows how to obtain channel metadata for Event 2.
#
#
import sys
import time
import copy
import getopt
from bdslib import *

def bdsEventsList(bds):
	""" Function to display events """
	err	= BError();
	selection = Selection();
	
	# Set up selection
	selection.startTime.setFirst();
	selection.endTime.setLast();

	(err, events) = bds.eventGetList(selection);
	if(err):
		return err;

	if(events.size() == 0):
		return err.set(1, "No Events selected");

	for i in range(0, events.size()):
		ev = events[i];

		print("Event.id: ", ev.id);
		print("Event.type: ", ev.type);
		print("Event.title: ", ev.title);
		
		for k in ev.extra.keys():
			print("Event.%s: %s" % (k, ev.extra[k]));
		
		for c in ev.dataChannels:
			print("Event.datachannel: %s:%s:%s:%s" % (c.network, c.station, c.channel, c.source));
		
	return err;

def main():
	hostName = "localhost";
	
	# Create DataAccess object to connect to BDS Server
	bds = AdminAccess();

	# Connect to the DataAccess service
	err = bds.connectService("//" + hostName + "/bdsAdminAccess");
	if(err):
		print("Error: " + str(err) + "\n");
		return 1;

	# Connect to service
	err = bds.connect("testAdmin", "beam00");
	if(err):
		print("Error: " + str(err) + "\n");
		return 1;
	
	(err, version, name) = bds.getVersion();
	if(err):
		print("Error: " + str(err) + "\n");
		return 1;
	print("Version:" , version, "Name:", name);

	err = bdsEventsList(bds);
	if(err):
		print("Error:", err.getErrorNo(), err.getString());
		return 1;
		
	return 0;

if __name__ == "__main__":
	main();
