#!/usr/bin/python
################################################################################
#	BdsEvents2.py	BDS API example code for a BDS Event Client
#	T.Barnaby,	BEAM Ltd,	2021-09-20
################################################################################
#
# This example shows how to obtain channel metadata for Event 2.
#
#
import sys
import time
import copy
import getopt
from bdslib import *

def eventSelection(bds, eventId):
	""" Get data selection given eventid """
	selection = Selection();

	selection.eventId = eventId;

	(err, events) = bds.eventGetList(selection);
	if(err):
		return (err, None);

	if(events.size() == 0):
		return (err.set(1, "No Events selected: Requires event id or title set to match events and the time range to contain the event"), None);

	if(events.size() != 1):
		return (err.set(1, "Multiple events selected"), None);

	selection.startTime = events[0].startTime;
	selection.endTime = events[0].endTime;
	selection.channels = events[0].dataChannels;

	return (err, selection);

def bdsChannelInfo(bds):
	""" Function to display event ChannelInfo """
	err	= BError();
	
	# Set up selection
	(err, selection) = eventSelection(bds, 2);
	if(err):
		return err;

	#bdsDumpSelection(selection);

	# Get list of stations available
	(err, channelInfos) = bds.metadataGetChannelInfo(selection);
	if(err):
		return err.set(1, "Error: Getting channel information: " + err.getString());
	
	for i in range(0, channelInfos.channels.size()):
		ci = channelInfos.channels[i][0];

		print("Chan: %s:%s:%s:%s %e %s" % (ci.channel.network, ci.channel.station, ci.channel.channel, ci.source, ci.calibration.calibrationFactor, ci.calibration.calibrationUnits));

		
	return err;

def main():
	hostName = "localhost";
	
	# Create DataAccess object to connect to BDS Server
	bds = AdminAccess();

	# Connect to the DataAccess service
	err = bds.connectService("//" + hostName + "/bdsAdminAccess");
	if(err):
		print("Error: " + str(err) + "\n");
		return 1;

	# Connect to service
	err = bds.connect("testAdmin", "beam00");
	if(err):
		print("Error: " + str(err) + "\n");
		return 1;
	
	(err, version, name) = bds.getVersion();
	if(err):
		print("Error: " + str(err) + "\n");
		return 1;
	print("Version:" , version, "Name:", name);

	err = bdsChannelInfo(bds);
	if(err):
		print("Error:", err.getErrorNo(), err.getString());
		return 1;
		
	return 0;

if __name__ == "__main__":
	main();
