#!/usr/bin/python
################################################################################
#	BdsMetaData6.py		BDS API example code for a BDS MetaData Client
#				T.Barnaby,	BEAM Ltd,	2016-04-22
################################################################################
#
# This example shows how to obtain data avilability
# The example assumes the BDS test data is installed.
#
#
import sys
import time
import copy
import getopt
from bdslib import *

# Function to display data availability
def bdsAvailability(bds):
	err	= BError();
	selection = Selection();
	
	# Set up selection
	selection.startTime.setString("2008-01-01T00:00:00.000000");
	selection.endTime.setString("2008-01-01T00:01:00.000000");
	selection.channels.append(SelectionChannel("TT", "TSA", "", ""));
	# bdsDumpSelection(selection);

	# Get list of stations available
	(err, availList) = bds.dataAvailability(selection, 10);
	if(err):
		return err.set(1, "Error: Getting data availability: " + err.getString());
	
	for i in range(0, availList.size()):
		avail = availList[i];
		print("Avail: %s:%s:%s:%s" % (avail.network, avail.station, avail.channel, avail.source));
		for i1 in range(0, len(avail.segments)):
			seg = avail.segments[i1];
			print("\tSeg: %s %s %d" % (seg.startTime.getString(), seg.endTime.getString(), seg.availType));

		
	return err;

def main():
	hostName = "localhost";
	
	# Create DataAccess object to connect to BDS Server
	bds = AdminAccess();

	# Connect to the DataAccess service
	err = bds.connectService("//" + hostName + "/bdsAdminAccess");
	if(err):
		print("Error: " + str(err) + "\n");
		return 1;

	# Connect to service
	err = bds.connect("testAdmin", "beam00");
	if(err):
		print("Error: " + str(err) + "\n");
		return 1;
	
	(err, version, name) = bds.getVersion();
	if(err):
		print("Error: " + str(err) + "\n");
		return 1;
	print("Version:" , version, "Name:", name);

	err = bdsAvailability(bds);
	if(err):
		print("Error:", err.getErrorNo(), err.getString());
		return 1;
		
	return 0;

if __name__ == "__main__":
	main();
