/*******************************************************************************
 *	BDspFilterDesign.h	Filter Design
 *			T.Barnaby,	BEAM Ltd,	2006-03-02
 *******************************************************************************
 */
#ifndef BDspFilterDesign_H
#define BDspFilterDesign_H	1

#include <BDspMain.h>
#include <BString.h>

void bdspBilinear(BDspArrayFloat iz, BDspArrayFloat ip);

class BDspFilterDesign {
public:
	enum Type	{ LowPass, HighPass, BandPass };
	
			BDspFilterDesign();
			BDspFilterDesign(BDspArrayFloat btaps, BDspArrayFloat ataps = BDspArrayFloat());
			BDspFilterDesign(BDspArrayDouble btaps, BDspArrayDouble ataps = BDspArrayDouble());
			BDspFilterDesign(BUInt numTaps, double* btaps, double* ataps = 0);

	void		setTaps(BDspArrayDouble b, BDspArrayDouble a = BDspArrayDouble());
	void		setTaps(BDspArrayFloat b, BDspArrayFloat a = BDspArrayFloat());
	void		setTaps(BUInt numTaps, double* btaps, double* ataps = 0);
	BString		getString();

public:	
	BDspArrayDouble	btapsDouble;		///< B Filter taps in double form
	BDspArrayDouble	atapsDouble;		///< A Filter taps in double form
	BDspArrayFloat	btapsFloat;		///< B Filter taps in float form
	BDspArrayFloat	atapsFloat;		///< A Filter taps in float form
};

BDspFilterDesign bdspFirDesignLowPass(double sampleRate, double freq, double transitionWidth);
BDspFilterDesign bdspFirDesignHighPass(double sampleRate, double freq, double transitionWidth);
BDspFilterDesign bdspFirDesignBandPass(double sampleRate, double lowFreq, double highFreq, double transitionWidth);
BDspFilterDesign bdspButterworthDesign(BDspFilterDesign::Type type, double sampleRate, double freq, int order);
BDspFilterDesign bdspFirDesignHilbert(int numTaps);
BDspFilterDesign bdspFirDesignDifferentiator(int numTaps);

#endif
