/*******************************************************************************
 *	BDspFmDemodulateATan.h	FM Demodulator Class
 *				T.Barnaby,	BEAM Ltd,	2006-09-29
 *******************************************************************************
 */
#ifndef BDspFmDemodulateATan_H
#define BDspFmDemodulateATan_H	1

#include <BDspMain.h>
#include <BDspFifo.h>
#include <BDspFilterFir.h>
#include <BDspFilterHilbert.h>


/// This class implements an FM Demodulator using a Hilbert transform
class BDspFmDemodulateATan {
public:
			BDspFmDemodulateATan(double sampleRate, double centerFreq, double squelch = 0.25, double modIndex = 0.33);

	void		setCenterFreq(double freq);	///< Set the centre frequency where the output is 0.0
	BError		process(BUInt numSamples,  BDspSample* sigIn, BDspSample* sigOut);	///< Process the next set of samples to yield numSamples (note needs more input samples than numSamples)

	BUInt		numInputNeeded();		///< Returns the number of extra input samples needed
private:
	double			osampleRate;		///< The overal sample rate
	double			ocenterFreq;		///< The centre frequency
	double			osquelch;		///< The squelch level, signal levels below this return 0.0
	double			omodIndex;		///< The FM modulation index as a fraction of the carrier frequency
	BDspFilterHilbert	ohilbert;		///< Hilbert filter
	BDspFilterFir		odiff;			///< Differentiation filter
	BDspArrayCSample	ocsig;			///< Complex signal
	BDspArraySample		osig1;			///< Arctan'd signal
};

/// This class implements an FM Demodulator using a Hilbert transform
class BDspFmDemodulateATanFifo : public BDspFifoProcess {
public:
			BDspFmDemodulateATanFifo(BDspFifo& input, BDspFifo& output, double sampleRate, double centerFreq, double squelch = 0.25, double modIndex = 0.33);

	void		setCenterFreq(double freq);	///< Set the centre frequency where the output is 0.0
	BError		process(BUInt numSamples);	///< Process the next set of samples to yield numSamples (note needs more input samples than numSamples)
private:
	BDspFmDemodulateATan	ofmDemod;		///< The FM Demodulation process
};

#endif
