/*******************************************************************************
 *	BdsDataFileAd22.h	BDRS Data File Access
 *			T.Barnaby,	BEAM Ltd,	2014-10-08
 *******************************************************************************
 */
#ifndef BdsDataFileAd22_H
#define	BdsDataFileAd22_H

#include <BdsDataFile.h>

namespace Bds {

/// Data file convertor for AD22 format files.
class DataFileAd22 : public DataFile{
public:
				DataFileAd22();

	int			getFeatures();						///< Get bitmask of supported features
	DataOrder		getDataOrder();
	BString			getFixesInfo();						///< Get readable list of fixes that can be applied to faulty data files

	BError			getInfo(DataInfo& dataInfo, DataFileOptions options, BList<DataError>& errors);
	BError			readData(BUInt32 channel, BUInt segment, BUInt32 blockNumber, DataBlock& data);

	static DataFormats	getFormats();
private:
	BError			readBlock(BUInt32 channel, BUInt64 pos, DataBlock& data);
	BError			getTimeCode(BTimeStamp startTime, BTimeStampMs& timeCode);

	int			omagic;
	int			oyear;
	int			oblockYear;
	BUInt32			oblockSize;
	double			osampleRate;
	DataInfo		odataInfo;
	BArray<DataBlockPos>	oblockPositions;
};

}
#endif
