/*******************************************************************************
 *	BdsDataFileCss.h	CSS Data File Access
 *			T.Barnaby,	BEAM Ltd,	2015-03-02
 *******************************************************************************
 */
#ifndef BdsDataFileCss_H
#define	BdsDataFileCss_H

#include <BdsDataFile.h>
#include <BdsSeedType.h>

namespace Bds {

/// DataFileCss internal CSS data type
class DataFileCssData : public BdsSeedType {
public:
			DataFileCssData();
			~DataFileCssData();
	BError		set(BString line);
	
	BString		sta;
	BString		chan;
	double		startTime;
	int		wfid;
	int		chanid;
	int		jdate;
	double		endTime;
	int		nsamp;
	double		sampleRate;
	double		calibrationFactor;
	double		calibrationFreq;
	BString		instType;
	BString		segtype;
	BString		datatype;
	BString		clip;
	BString		dirName;
	BString		fileName;
	BUInt32		fileOffset;
	int		commId;
	BString		loadDate;
	
	BFile*		file;
	BUInt32		sampleFormat;
	BUInt32		sampleSize;
	int		sampleBigEndian;
};

/// Data file convertor for CSS format files.
class DataFileCss : public DataFile {
public:
				DataFileCss();

	int			getFeatures();						///< Get bitmask of supported features
	DataOrder		getDataOrder();

	BError			getInfo(DataInfo& dataInfo, DataFileOptions options, BList<DataError>& errors);
	BError			readData(BUInt32 channel, BUInt segment, BUInt32 blockNumber, DataBlock& data);

	static DataFormats	getFormats();
private:
	BError			getCssFormat(BString format, BUInt32& sampleFormat, BUInt32& sampleSize, int& sampleEndian);

	BUInt					oblockSamples;
	DataInfo				odataInfo;
	BArray<BArray<DataFileCssData> >	odataCss;
};

}
#endif
