/*******************************************************************************
 *	BdsDataFileLac.h	LAC/BDRS Data File Access
 *			T.Barnaby,	BEAM Ltd,	2014-11-04
 *******************************************************************************
 */
#ifndef BdsDataFileLac_H
#define	BdsDataFileLac_H

#include <BdsDataFile.h>

namespace Bds {

/// Data file convertor for LAC format files.
class DataFileLac : public DataFile{
public:
				DataFileLac();

	int			getFeatures();						///< Get bitmask of supported features
	DataOrder		getDataOrder();
	BString			getFixesInfo();						///< Get readable list of fixes that can be applied to faulty data files

	BError			getInfo(DataInfo& dataInfo, DataFileOptions options, BList<DataError>& errors);
	BError			readData(BUInt32 channel, BUInt segment, BUInt32 blockNumber, DataBlock& data);

	static DataFormats	getFormats();
private:
	BError			readBlock(BUInt32 channel, BUInt64 pos, DataBlock& data, BUInt64& posNext);

	int			omagic;
	int			oyear;
	int			oblockYear;
	BUInt32			oblockSize;
	double			osampleRate;
	DataInfo		odataInfo;
	BArray<DataBlockPos>	oblockPositions;
	BUInt32			obadBlocks;
};

}
#endif
