/*******************************************************************************
 *	BdsDataLib.h	Data File Access
 *			T.Barnaby,	BEAM Ltd,	2008-11-20
 *******************************************************************************
 */
#ifndef BdsDataLib_H
#define	BdsDataLib_H

#include <BdsDataFile.h>

namespace Bds {

BString fixedWidthValue(double v, int width);		///< This returns a double as a fixed width string truncating the data

/// @brief This class defines the interface for generic data file access.
/// @details It allows programs to get a list of all of the supported data formats and to get a suitable BDS data convertor for accessing the file.
class DataFormatAll {
public:
				DataFormatAll();
				~DataFormatAll();
				
	BError		formatList(DataFormats& formats);								/// Returns a list of all data converters
	BError		formatGet(BString format, DataFile*& dataFile, DataFormatSet formatSet = DataFormatSetNone);	/// Searches all of the BDS data converters to find out if any supports the given format. If one is found the appropriate data converter is initialised and a pointer to it returned in file.
	BString		formatGetExtension(BString format);								/// Returns the default file extension for the given format
	
protected:
	int		findFormat(DataFormats dataFormats, BString string, DataFormatSet formatSet);
};

extern DataFormatAll	dataFormatAll;

}
#endif
